=== modified file 'tests/test_webui.py'
--- tests/test_webui.py	2014-12-16 19:03:57 +0000
+++ tests/test_webui.py	2014-12-16 20:49:10 +0000
@@ -81,9 +81,11 @@
         # Click the submit button without inputting any fields
         submit = get_element_by_css('input[type="submit"]')
         click_button(submit, wait=True)
+        # There should be 3 required fields
+        # Either sources or merge proposals is required too, but won't
+        # display an error until it gets past this point
         require_errors = get_elements(css_class="error")
-        # There should be 4 required fields
-        self.assertEquals(len(require_errors), 4)
+        self.assertEqual(3, len(require_errors))
         for error_span in require_errors:
             assert_displayed(error_span)
 
@@ -118,8 +120,8 @@
         # Submit the form with the required fields.
         title = get_element_by_css('input[name="title"]')
         write_textfield(title, 'Testing Sources & MPs')
-        owner = get_element_by_css('input[name="owner"]')
-        write_textfield(owner, 'foo@bar.com')
+        landers = get_element_by_css('input[name="landers"]')
+        write_textfield(landers, 'foo@bar.com')
         sources = get_element_by_css('textarea[name="sources"]')
         write_textfield(sources, 'foo\nbar')
         mps = get_element_by_css('textarea[name="merge_proposals"]')
@@ -128,6 +130,8 @@
             'https://code.launchpad.net/~x/foo/a_branch/+merge/1\n'
             'https://code.launchpad.net/~x/foo/a_branch/+merge/2\n'
             'https://code.launchpad.net/~x/baz/a_branch/+merge/3')
+        test_notes = get_element_by_css('textarea[name="test_notes"]')
+        write_textfield(test_notes, 'test this')
         submit = get_element_by_css('input[type="submit"]')
         click_button(submit, wait=True)
 
@@ -161,6 +165,27 @@
               'Conflicts:']],
             [s.text.splitlines() for s in subtickets])
 
+    def test_create_ticket_fails_without_sources_or_mps(self):
+        # Either source packages or merge proposals must be defined
+        go_to('/create')
+        wait_for(get_element, tag='form')
+        # Fill in all the fields except sources and mps
+        title = get_element_by_css('input[name="title"]')
+        write_textfield(title, 'Testing WebUI')
+        landers = get_element_by_css('input[name="landers"]')
+        write_textfield(landers, 'foo@bar.com')
+        test_notes = get_element_by_css('textarea[name="test_notes"]')
+        write_textfield(test_notes, 'test this')
+        submit = get_element_by_css('input[type="submit"]')
+        click_button(submit, wait=True)
+        # Check that we get the right error
+        errors = get_elements(css_class="error")
+        self.assertEqual(2, len(errors))
+        for error in errors:
+            self.assertEqual(
+                'Source Packages or Merge Proposals must be supplied',
+                error.text)
+
     def test_edit_ticket(self):
         # Edit a ticket via WebUI form.
         go_to('/')
@@ -305,8 +330,8 @@
         title = get_element_by_css('input[name="title"]')
         title_text = 'Testing Invalid MPs at {}'.format(time.asctime())
         write_textfield(title, title_text)
-        owner = get_element_by_css('input[name="owner"]')
-        write_textfield(owner, 'foo@bar.com')
+        landers = get_element_by_css('input[name="landers"]')
+        write_textfield(landers, 'foo@bar.com')
         sources = get_element_by_css('textarea[name="sources"]')
         write_textfield(sources, 'foo\nbar')
         mps = get_element_by_css('textarea[name="merge_proposals"]')
@@ -315,6 +340,8 @@
             'https://code.launchpad.net/~x/foo/a_branch/+merge/1\n'
             'https://code.launchpad.net/~x/foo/a_branch/+merge/abc\n'
             'https://code.launchpad.net/~x/baz/a_branch/+merge/3')
+        test_notes = get_element_by_css('textarea[name="test_notes"]')
+        write_textfield(test_notes, 'test this')
         submit = get_element_by_css('input[type="submit"]')
         click_button(submit, wait=True)
         error = get_element_by_css('span.error')
@@ -340,8 +367,12 @@
         title = get_element_by_css('input[name="title"]')
         title_text = 'Editing with Invalid MPs at {}'.format(time.asctime())
         write_textfield(title, title_text)
-        owner = get_element_by_css('input[name="owner"]')
-        write_textfield(owner, 'foo@bar.com')
+        landers = get_element_by_css('input[name="landers"]')
+        write_textfield(landers, 'foo@bar.com')
+        sources = get_element_by_css('textarea[name="sources"]')
+        write_textfield(sources, 'foo\nbar')
+        test_notes = get_element_by_css('textarea[name="test_notes"]')
+        write_textfield(test_notes, 'test this')
 
         submit = get_element_by_css('input[type="submit"]')
         click_button(submit, wait=True)

